@@ -78,12 +78,13 @@ def full_example(collection, examples):
                 r.newline()
 
 
-        if 'post' in 'example':
+        if 'post' in example:
             r.content(example.post)
             r.newline()
 
-        r.codeblock(content=example.results,
-                    language='javascript')
+        if example.results is not None:
+            r.codeblock(content=example.results,
+                        language='javascript')
 
         if 'final' in example:
             r.newline()
